@@ -52,6 +52,8 @@ class Streamlink(object):
             "hls-segment-timeout": 10.0,
             "hls-timeout": 60.0,
             "hls-playlist-reload-attempts": 3,
+            "hls-start-offset": 0,
+            "hls-duration": None,
             "http-stream-timeout": 60.0,
             "ringbuffer-size": 1024 * 1024 * 16,  # 16 MB
             "rtmp-timeout": 60.0,
